@@ -44,9 +44,6 @@ public:
 
     void resetPayeeIdentifiers(const QList< ::payeeIdentifier >& list = QList< ::payeeIdentifier >());
 
-    void loadXML(QDomElement node);
-    void writeXML(QDomDocument document, QDomElement parent) const;
-
 protected:
     QList< ::payeeIdentifier > m_payeeIdentifiers;
 };
