@@ -9,9 +9,11 @@
 
 #include <QObject>
 
+#include "mymoneytestutils.h"
+
 class MyMoneySplit;
 
-class MyMoneySplitTest : public QObject
+class MyMoneySplitTest : public QObject, public MyMoneyTestBase
 {
     Q_OBJECT
 
@@ -33,6 +35,8 @@ private Q_SLOTS:
     void testSetAction();
     void testIsAutoCalc();
     void testUnaryMinus();
+    void testPrice();
+    void testSetPrice();
     void testPriceCalculation();
     void testPriceAssignment();
 };
