@@ -6,9 +6,9 @@
 #ifndef SEPAONLINETASKSLOADER_H
 #define SEPAONLINETASKSLOADER_H
 
-#include <kmymoney/plugins/onlinepluginextended.h>
+#include <kmymoney/interfaces/onlinepluginextended.h>
 
-class sepaOnlineTasksLoader : public QObject, public KMyMoneyPlugin::onlineTaskFactory
+class sepaOnlineTasksLoader : public KMyMoneyPlugin::onlineTaskFactory
 {
     Q_OBJECT
     Q_INTERFACES(KMyMoneyPlugin::onlineTaskFactory)
