@@ -6,8 +6,6 @@
 
 #include "pivottable-test.h"
 
-#include <KLocalizedString>
-
 #include <QFile>
 #include <QList>
 #include <QRegularExpression>
@@ -94,11 +92,6 @@ void writeTable(const PivotTable& table, const QString& basename = QString())
     writeTabletoXML(table, basename);
 }
 
-void PivotTableTest::initTestCase()
-{
-    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kmymoney"));
-}
-
 void PivotTableTest::init()
 {
     file = MyMoneyFile::instance();
