@@ -27,6 +27,7 @@
 // Project Includes
 
 #include "accountsmodel.h"
+#include "alkimia/alkenvironment.h"
 #include "icons.h"
 #include "investtransactioneditor.h"
 #include "journalmodel.h"
@@ -218,11 +219,14 @@ public:
                                          ? QString()
                                          : MyMoneyUtils::formatMoney(-value, currency));
                     }
-                } else {
-                    rc.lines << opt.text;
                 }
             }
             rc.lines.removeAll(QString());
+            // in case there is no data, we simply return a blank one-liner
+            // which forces to paint the background in the correct color
+            if (rc.lines.isEmpty()) {
+                rc.lines << QStringLiteral(" ");
+            }
 
         } else if (index.column() == JournalModel::Column::Deposit) {
             const auto havePayeeColumn = !m_view->isColumnHidden(JournalModel::Payee);
@@ -457,7 +461,6 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
     opt.state &= ~QStyle::State_HasFocus;
 
     QAbstractItemView* view = qobject_cast<QAbstractItemView*>(parent());
-    const auto editCol = (d->m_view) ? d->m_view->horizontalHeader()->logicalIndexAt(0) : 0;
     const auto editIndex = index.model()->index(index.row(), d->m_editorCol, index.parent());
     const auto editWidget = (d->m_view) ? d->m_view->indexWidget(editIndex) : nullptr;
 
@@ -469,17 +472,6 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
         opt.state &= ~QStyle::State_Active;
     }
 
-    // if the widget has a different size than what we can paint on
-    // then we adjust the size of the widget so that the focus frame
-    // can be painted correctly using a WidgetHintFrame. The editor
-    // only uses the first column across the whole width
-    if (editWidget && (index.column() == editCol)) {
-        auto size = editWidget->size();
-        if (size.width() != opt.rect.size().width()) {
-            editWidget->resize(size);
-        }
-    }
-
     painter->save();
 
     // Background
@@ -490,10 +482,10 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
 
     style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, editWidget ? editWidget : opt.widget);
 
-    QPalette::ColorGroup cg;
-
     // Do not paint text if the edit widget is shown
     if (editWidget == nullptr) {
+        QPalette::ColorGroup cg;
+
         if(view && (index.column() == JournalModel::Column::Detail)) {
             if(view->currentIndex().row() == index.row()) {
                 opt.state |= QStyle::State_HasFocus;
@@ -625,6 +617,16 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
                 }
             }
         }
+    } else {
+        // Skip painting the CE_FocusFrame on Windows and with AppImages
+        // because it seems to be the cause that the background of the
+        // editor is painted completely black.
+#ifndef Q_OS_WIN
+        if (!AlkEnvironment::isRunningAsAppImage()) {
+            // paint focus frame around edit widget
+            style->drawControl(QStyle::CE_FocusFrame, &opt, painter, editWidget);
+        }
+#endif
     }
 
     painter->restore();
