@@ -280,6 +280,7 @@ public:
     SelectedObjects m_equitySelections;
     SelectedObjects m_securitySelections;
     SelectedObjects m_externalSelections;
+    int m_selectedRow;
 };
 
 KInvestmentView::KInvestmentView(QWidget *parent) :
@@ -292,6 +293,40 @@ KInvestmentView::KInvestmentView(QWidget *parent) :
     connect(pActions[eMenu::Action::UpdatePriceManually], &QAction::triggered, this, &KInvestmentView::slotUpdatePriceManually);
     connect(pActions[eMenu::Action::EditSecurity], &QAction::triggered, this, &KInvestmentView::slotEditSecurity);
     connect(pActions[eMenu::Action::DeleteSecurity], &QAction::triggered, this, &KInvestmentView::slotDeleteSecurity);
+
+    // For an unknown reason, the model structure setup for this view causes a crash
+    // in case the last visible item is removed from the base model. This can be avoided
+    // by blocking all signals between the topmost model and the view during the deletion
+    // of the object in the base model (accountsModel). A bit of house cleaning needs to
+    // be done after the signals are unblocked because the current selected object
+    // certainly has changed.
+    connect(MyMoneyFile::instance()->accountsModel(), &AccountsModel::aboutToRemoveAccounts, this, [&]() {
+        Q_D(KInvestmentView);
+        if (d->m_equitiesProxyModel) {
+            d->m_equitiesProxyModel->blockSignals(true);
+            d->m_selectedRow = d->ui->m_equitiesTree->currentIndex().row();
+        }
+    });
+
+    connect(MyMoneyFile::instance()->accountsModel(), &AccountsModel::accountsRemoved, this, [&]() {
+        Q_D(KInvestmentView);
+        if (d->m_equitiesProxyModel) {
+            d->m_equitiesProxyModel->blockSignals(false);
+            d->m_equitiesProxyModel->invalidate();
+
+            if (d->m_selectedRow >= d->m_equitiesProxyModel->rowCount()) {
+                --d->m_selectedRow;
+            }
+
+            const auto idx = d->m_equitiesProxyModel->index(d->m_selectedRow, 0, d->ui->m_equitiesTree->rootIndex());
+            d->ui->m_equitiesTree->setCurrentIndex(idx);
+            if (!idx.isValid()) {
+                d->m_equitySelections.clearSelections(SelectedObjects::Account);
+                d->m_selections = d->m_equitySelections;
+                Q_EMIT requestSelectionChange(d->m_selections);
+            }
+        }
+    });
 }
 
 KInvestmentView::~KInvestmentView()
@@ -363,7 +398,7 @@ void KInvestmentView::showEvent(QShowEvent* event)
 
         connect(d->ui->m_securitiesTree, &QWidget::customContextMenuRequested, this, [&](const QPoint& pos) {
             Q_D(KInvestmentView);
-            Q_EMIT requestCustomContextMenu(eMenu::Menu::Security, d->ui->m_equitiesTree->viewport()->mapToGlobal(pos));
+            Q_EMIT requestCustomContextMenu(eMenu::Menu::Security, d->ui->m_securitiesTree->viewport()->mapToGlobal(pos));
         });
 
         connect(d->ui->m_equitiesTree->selectionModel(),
@@ -521,7 +556,10 @@ void KInvestmentView::updateActions(const SelectedObjects& selections)
         skip.fill(false);
         skip.setBit((int)eStorage::Reference::Price);
         pActions[eMenu::Action::EditSecurity]->setEnabled(true);
+        pActions[eMenu::Action::UpdatePriceManually]->setEnabled(true);
         pActions[eMenu::Action::DeleteSecurity]->setDisabled(file->isReferenced(securityId, skip));
+        const auto sec = file->securitiesModel()->itemById(securityId);
+        pActions[eMenu::Action::UpdatePriceOnline]->setDisabled(sec.value("kmm-online-source").isEmpty());
     }
 
     d->m_externalSelections = selections;
@@ -573,8 +611,18 @@ void KInvestmentView::slotDeleteInvestment()
 void KInvestmentView::slotUpdatePriceOnline()
 {
     Q_D(KInvestmentView);
-    if (!d->currentEquity().id().isEmpty()) {
-        QPointer<KEquityPriceUpdateDlg> dlg = new KEquityPriceUpdateDlg(nullptr, d->currentEquity().currencyId());
+
+    QString currencyId;
+    auto tab = static_cast<eView::Investment::Tab>(d->ui->m_tab->currentIndex());
+
+    if (tab == eView::Investment::Equities) {
+        currencyId = d->currentEquity().currencyId();
+    } else {
+        currencyId = d->currentSecurity().id();
+    }
+    if (!currencyId.isEmpty()) {
+        QPointer<KEquityPriceUpdateDlg> dlg = new KEquityPriceUpdateDlg(nullptr, currencyId);
+        dlg->setSearchShortcut(pActions[eMenu::Action::ShowFilterWidget]->shortcut());
         if ((dlg->exec() == QDialog::Accepted) && (dlg != nullptr))
             dlg->storePrices();
         delete dlg;
