@@ -216,13 +216,15 @@ void LedgerViewPage::setAccount(const MyMoneyAccount& acc)
 
     switch(acc.accountType()) {
     case eMyMoney::Account::Type::Investment:
-        columns = { JournalModel::Column::Number,
-                    JournalModel::Column::Account,
-                    JournalModel::Column::CostCenter,
-                    JournalModel::Column::Amount,
-                    JournalModel::Column::Payment,
-                    JournalModel::Column::Deposit,
-                  };
+        columns = {
+            JournalModel::Column::Invisible,
+            JournalModel::Column::Number,
+            JournalModel::Column::Account,
+            JournalModel::Column::CostCenter,
+            JournalModel::Column::Amount,
+            JournalModel::Column::Payment,
+            JournalModel::Column::Deposit,
+        };
         d->ui->m_ledgerView->setColumnsHidden(columns);
         columns = {
             JournalModel::Column::Date,
@@ -238,14 +240,16 @@ void LedgerViewPage::setAccount(const MyMoneyAccount& acc)
         break;
 
     default:
-        columns = { JournalModel::Column::Account,
-                    JournalModel::Column::Security,
-                    JournalModel::Column::CostCenter,
-                    JournalModel::Column::Quantity,
-                    JournalModel::Column::Price,
-                    JournalModel::Column::Amount,
-                    JournalModel::Column::Value,
-                  };
+        columns = {
+            JournalModel::Column::Invisible,
+            JournalModel::Column::Account,
+            JournalModel::Column::Security,
+            JournalModel::Column::CostCenter,
+            JournalModel::Column::Quantity,
+            JournalModel::Column::Price,
+            JournalModel::Column::Amount,
+            JournalModel::Column::Value,
+        };
         d->ui->m_ledgerView->setColumnsHidden(columns);
         columns = {
             JournalModel::Column::Date,
@@ -359,9 +363,14 @@ void LedgerViewPage::slotRequestSelectionChanged(const SelectedObjects& selectio
             MyMoneyMoney balance;
             const auto journalEntryIds = selections.selection(SelectedObjects::JournalEntry);
             for (const auto& journalEntryId : qAsConst(journalEntryIds)) {
-                const auto idx = MyMoneyFile::instance()->journalModel()->indexById(journalEntryId);
-                if (idx.isValid()) {
-                    balance += idx.data(eMyMoney::Model::SplitSharesRole).value<MyMoneyMoney>();
+                const auto ledgerIdx = MyMoneyFile::instance()->journalModel()->indexById(journalEntryId);
+                if (ledgerIdx.isValid()) {
+                    balance += ledgerIdx.data(eMyMoney::Model::SplitSharesRole).value<MyMoneyMoney>();
+                } else {
+                    const auto scheduleIdx = MyMoneyFile::instance()->schedulesJournalModel()->indexById(journalEntryId);
+                    if (scheduleIdx.isValid()) {
+                        balance += scheduleIdx.data(eMyMoney::Model::SplitSharesRole).value<MyMoneyMoney>();
+                    }
                 }
             }
             d->selectedTotal = balance;
@@ -429,10 +438,6 @@ bool LedgerViewPage::executeAction(eMenu::Action action, const SelectedObjects&
             QPointer<TabOrderDialog> tabOrderDialog = new TabOrderDialog(d->ui->m_ledgerView);
             auto tabOrderWidget = static_cast<TabOrderEditorInterface*>(editor->qt_metacast("TabOrderEditorInterface"));
             tabOrderDialog->setTarget(tabOrderWidget);
-            auto tabOrder = editor->property("kmm_defaulttaborder").toStringList();
-            tabOrderDialog->setDefaultTabOrder(tabOrder);
-            tabOrder = editor->property("kmm_currenttaborder").toStringList();
-            tabOrderDialog->setTabOrder(tabOrder);
 
             if ((tabOrderDialog->exec() == QDialog::Accepted) && tabOrderDialog) {
                 tabOrderWidget->storeTabOrder(tabOrderDialog->tabOrder());
